@@ -26,8 +26,9 @@
 #define TDENETWORKMANAGER_PLUGIN_H
 
 #include <tqobject.h>
+#include <kdemacros.h>
 
-class Plugin : public TQObject
+class KDE_EXPORT Plugin : public TQObject
 {
 	Q_OBJECT
   
