@@ -61,6 +61,10 @@ class WiredDeviceTrayPrivate
 void WiredDeviceTray::newConnection()
 {
 	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
+	if (!nm)
+	{
+		return;
+	}
 
 	// create a new wired connection
 	TDENetworkConnection* conn = new TDEWiredEthernetConnection();
@@ -75,13 +79,19 @@ void WiredDeviceTray::newConnection()
 void WiredDeviceTray::addMenuItems(TDEPopupMenu* menu)
 {
 	TDENetworkDevice* dev = dynamic_cast<TDENetworkDevice*>(hwdevices->findByUniqueID(d->dev));
+	if (!dev)
+	{
+		return;
+	}
 
 	// device title
 	Subhead* subhead = new Subhead (menu, "subhead", TQString("Wired Connection (%1)").arg(dev->deviceNode()), SmallIcon("wired", TQIconSet::Automatic));
 	menu->insertItem (subhead, -1, -1);
 
 	TDENetworkConnectionManager* deviceConnMan = dev->connectionManager();
-	if (!deviceConnMan->deviceInformation().managed) {
+	TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
+	if (!nm || !deviceConnMan|| !deviceConnMan->deviceInformation().managed)
+	{
 		// device is not managed by NM -> do not show any connections
 		subhead = new Subhead(menu, "subhead2", i18n("Not managed"), SmallIcon("no", TQIconSet::Automatic));
 		menu->insertItem(subhead, -1, -1);
@@ -92,7 +102,6 @@ void WiredDeviceTray::addMenuItems(TDEPopupMenu* menu)
 		menu->insertItem(subhead, -1, -1);
 	}
 	else {
-		TDEGlobalNetworkManager* nm = TDEGlobal::networkManager();
 		TDENetworkConnection* active_conn = NULL;
 		if ((!(deviceConnMan->deviceInformation().statusFlags & TDENetworkConnectionStatus::Disconnected))
 			&& (!(deviceConnMan->deviceInformation().statusFlags & TDENetworkConnectionStatus::Invalid))) {
